[49248] trunk/dports/devel/hg-forest

blb at macports.org blb at macports.org
Mon Apr 6 00:02:17 PDT 2009


Revision: 49248
          http://trac.macports.org/changeset/49248
Author:   blb at macports.org
Date:     2009-04-06 00:02:16 -0700 (Mon, 06 Apr 2009)
Log Message:
-----------
devel/hg-forest - update to 20090203

Modified Paths:
--------------
    trunk/dports/devel/hg-forest/Portfile
    trunk/dports/devel/hg-forest/files/forest.py

Modified: trunk/dports/devel/hg-forest/Portfile
===================================================================
--- trunk/dports/devel/hg-forest/Portfile	2009-04-06 03:52:57 UTC (rev 49247)
+++ trunk/dports/devel/hg-forest/Portfile	2009-04-06 07:02:16 UTC (rev 49248)
@@ -3,7 +3,7 @@
 PortSystem          1.0
 PortGroup           python25 1.0
 name                hg-forest
-version             20081025
+version             20090203
 categories          devel mercurial
 maintainers         blb openmaintainer
 description         Mercurial extension for nested repositories

Modified: trunk/dports/devel/hg-forest/files/forest.py
===================================================================
--- trunk/dports/devel/hg-forest/files/forest.py	2009-04-06 03:52:57 UTC (rev 49247)
+++ trunk/dports/devel/hg-forest/files/forest.py	2009-04-06 07:02:16 UTC (rev 49248)
@@ -55,32 +55,42 @@
 import re
 import shutil
 
-from mercurial import cmdutil, commands, hg, hgweb, node, util
+from mercurial import cmdutil, commands, error, hg, hgweb, node, util
 from mercurial import localrepo, sshrepo, sshserver, httprepo, statichttprepo
 from mercurial.i18n import gettext as _
-from mercurial.repo import RepoError
 
 # For backwards compatibility, we need the following function definition.
 # If we didn't want that, we'd have just written:
 #     from mercurial.commands import 
-def findcmd(ui, cmd, table):
-    """Find and execute mercurial.*.findcmd(ui, cmd[, table])."""
+def findcmd(ui, cmd, table, strict=True):
+    """Find and execute mercurial.*.findcmd([ui,] cmd[, table, strict])."""
     try:
-        # ui argument was removed as of b4c035057d34
-        return findcmd.findcmd(cmd, table)
+        return findcmd.findcmd(cmd=cmd, table=table, strict=strict)
     except TypeError:
         try:
-            return findcmd.findcmd(ui, cmd, table)
+            return findcmd.findcmd(ui=ui, cmd=cmd, table=table)
         except TypeError:
             return findcmd.findcmd(ui, cmd)
 try:
     findcmd.findcmd = cmdutil.findcmd
     findcmd.__doc__ = cmdutil.findcmd.__doc__
-    findcmd.UnknownCommand = cmdutil.UnknownCommand
 except AttributeError:
     findcmd.findcmd = commands.findcmd
     findcmd.__doc__ = commands.findcmd.__doc__
-    findcmd.UnknownCommand = commands.UnknownCommand
+for m in (error, cmdutil, commands):
+    if hasattr(m, "UnknownCommand"):
+        findcmd.UnknownCommand = m.UnknownCommand
+        break
+try:
+    # Assign the exceptions explicitely to avoid demandload issues
+    import mercurial.repo
+    import mercurial.cmdutil
+    RepoError = mercurial.repo.RepoError
+    ParseError = mercurial.dispatch.ParseError
+except AttributeError:
+    import mercurial.error
+    RepoError = mercurial.error.RepoError
+    ParseError = mercurial.error.ParseError
 
 # For backwards compatibility, find the parseurl() function that splits
 # urls and revisions.  Mercurial 0.9.3 doesn't have this, so we need
@@ -1122,7 +1132,7 @@
 
     snapfile = snapshot or opts['snapfile']
     if not snapfile:
-        raise cmdutil.ParseError("fseed", _("invalid arguments"))
+        raise ParseError("fseed", _("invalid arguments"))
     forest = Forest(snapfile=snapfile)
     tip = opts['tip']
     dest = opts['root']
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.macosforge.org/pipermail/macports-changes/attachments/20090406/8abda2c7/attachment-0001.html>


More information about the macports-changes mailing list